package com.justinmind.exporttojira.handlers;

import java.awt.Desktop;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.io.Writer;
import java.util.List;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.handlers.HandlerUtil;
import org.eclipse.jface.dialogs.MessageDialog;

import com.justinmind.prototyper.api.API;
import com.justinmind.prototyper.api.IPrototype;
import com.justinmind.prototyper.api.comment.IComment;
import com.justinmind.prototyper.api.comment.IRootComment;

/**
 * Our sample handler extends AbstractHandler, an IHandler base class.
 * @see org.eclipse.core.commands.IHandler
 * @see org.eclipse.core.commands.AbstractHandler
 */
public class ExportToJIRAHandler extends AbstractHandler {
	/**
	 * The constructor.
	 */
	public ExportToJIRAHandler() {
	}

	/**
	 * the command has been executed, so extract extract the needed information
	 * from the application context.
	 */
	public Object execute(ExecutionEvent event) throws ExecutionException {
		IWorkbenchWindow window = HandlerUtil.getActiveWorkbenchWindowChecked(event);
		exportToJIRA();
		return null;
	}
	
	protected void exportToJIRA(){
		try {
			IPrototype prototype = API.getPrototypeLoader().loadPrototype();
		    List<IRootComment> comments = prototype.getApiComments();
		    String content = "Summary, Assignee, Reporter, Issue Type, Description, Priority\n";
		    for (IRootComment iRootComment : comments) {
				content+=getCommentTexts(iRootComment)+"\n";
			}
		    FileDialog dialog = new FileDialog(Display.getDefault().getActiveShell(), SWT.SAVE);
		    dialog.setFilterExtensions(new String[] { "*.csv" });
		    dialog.setOverwrite(true);
		    String path = dialog.open();
		    if (path != null) {
		      Writer output = null;
		      File file = new File(path);
		      FileWriter fw = null;
		      try {
		        fw = new FileWriter(file);
		          output = new BufferedWriter(fw);
		          output.write(content);
		          output.close();
		          Desktop.getDesktop().open(file);
		      } catch (IOException e) {
		        MessageDialog.openError(PlatformUI.getWorkbench().getActiveWorkbenchWindow().getShell(), "Error", e.getLocalizedMessage());
		      }
		    } else {
		      // show error
		    }
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
	}
	
	private String getCommentTexts(IComment comment) {
		String comment_text="";
		comment_text+=comment.getApiContent()+",";
		comment_text+=",";
		comment_text+=comment.getApiAuthor()+",";
		comment_text+="1,";
		comment_text+=comment.getApiContent()+",";
		if(comment.getApiCategory()!=null)
		comment_text+=comment.getApiCategory().getApiValue()+"\n";
		else
			comment_text+="\n";
		
		List<IComment> replies = comment.getApiReplies();
		for (IComment reply : replies) {
			comment_text+=getCommentTexts(reply)+"\n";
		}
		
		return comment_text;
	}
}
